#
# spec file for package python-terminado
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-terminado
Version:        0.18.1
Release:        1.2
Summary:        Terminals served to termjs using Tornado websockets
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyter/terminado
Source:         https://files.pythonhosted.org/packages/source/t/terminado/terminado-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling >= 0.25}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module ptyprocess}
BuildRequires:  %{python_module tornado >= 4}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ptyprocess
Requires:       python-tornado >= 4
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This is a Tornado websocket backend for the term.js Javascript terminal
emulator library.

It evolved out of pyxterm, which was part of GraphTerm (as lineterm.py), and
ultimately derived from the public-domain Ajaxterm code (also on Github as part
of QWeb).

%prep
%setup -q -n terminado-%{version}
sed -i '/addopts/ s/--durations 10 --color=yes//' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/jupyter/terminado/issues/21
donttest="test_max_terminals"
# somehow the reading from the spawned process does fail inside OBS
donttest+=" or test_basic"
# ?
donttest+=" or test_unique_processes"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/terminado
%{python_sitelib}/terminado-%{version}*-info

%changelog
* Fri Mar 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.18.1
  * Maintenance and upkeep improvements
* Thu Dec 28 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.18.0
  * code maintenance updates: typing, linting
  * drop Python 3.7
* Sun Jan  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.17.1
  * Don't split manually on linebreaks #209 (@incase)
* Thu Nov 24 2022 Arun Persaud <arun@gmx.de>
- update to version 0.17.0:
  * Maintenance and upkeep improvements
    + Clean up docs install #198 (@blink1073)
    + Maintenance cleanup #196 (@blink1073)
    + Maintenance cleanup #195 (@blink1073)
* Fri Sep 30 2022 Arun Persaud <arun@gmx.de>
- update to version 0.16.0:
  * Bugs fixed
    + Fix issue where large stdin writes can cause Tornado to hang
    [#189] (@KoopaKing)
  * Maintenance and upkeep improvements
    + Switch to using hatch version #186 (@blink1073)
    + Fix flake8 v5 compat #179 (@blink1073)
* Wed Jul 13 2022 Ben Greiner <code@bnavigator.de>
- Update build and test requirements
* Sat Jun  4 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * require pip, hatchling, swtich to pyproject build
- update to version 0.15.0:
  * no changelog available
- changes from version 0.14.0:
  * Add pre-commit
  * add mypy support
  * Switch to flit build backend
  * Switch to hatch backend
* Wed Mar  9 2022 Arun Persaud <arun@gmx.de>
- update to version 0.13.3:
  * Bugs fixed
    + Test ConPTY backend against pywinpty 2.0.5 #146 (@andfoy)
* Sat Mar  5 2022 Arun Persaud <arun@gmx.de>
- update to version 0.13.2:
  * Bugs fixed
    + Increase scrollback to 1000 #143 (@yusufbashi)
  * Maintenance and upkeep improvements
    + Add test for terminating the terminals and fix Windows terminal
    shutdown behavior #142 (@blink1073)
* Sat Jan 29 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * require python >= 3.7
- update to version 0.13.1:
  * Maintenance and upkeep improvements
    + python_requires is an option in setup.cfg #140 (@minrk)
- changes from version 0.13.0:
  * Enhancements made
    + Add pre_pty_read_hook in pty_read #136 (@Wh1isper)
  * Maintenance and upkeep improvements
    + Officially drop support for python 3.6 #137 (@blink1073)
    + Fix even more setup.cfg formatting #134 (@blink1073)
    + Fix more setup.cfg formatting #133 (@blink1073)
* Sun Oct 10 2021 Ben Greiner <code@bnavigator.de>
- update to version 0.12.1
  * correctly set the TERM variable
  * Replace deprecated unittest aliases
  * Clean up tests
  * Log terminal output
  * Switch select() to poll() in pty_read()
  * Fix blocking of pty_read when there isn't pty data ready to
    read
  * Support creating terminal given name in kwargs.
  * avoid persistent handle on IOLoop instance
  * async/await syntax
* Fri May 14 2021 Arun Persaud <arun@gmx.de>
- update to version 0.9.5:
  * Pin pywinpty version #98 (@jtpio)
- changes from version 0.9.4:
  * Allow non-strict decode for process output #95 (@dong-zeyu)
  * Switch to GitHub Actions #93 (@afshin)
  * Add generated changelog #92 (@blink1073)
- changes from version 0.9.3:
  * Make sure SIGPIPE has default handler set #91 (@dlukes)
* Sat Jan  9 2021 Arun Persaud <arun@gmx.de>
- update to version 0.9.2:
  * Add js files in package manifest
  * Add support to ppc64le
  * Fix config files for publication
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 0.9.1
  * no changelog provided
- Python <3.6 is no longer supported
- Skip two tests because of OBS specific limitations
* Mon Nov 18 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.8.3
  * Addkwargs to NamedTermManager.new_named_terminal
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Enable tests
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.8.2
  * Fix Delete Terminal Not Working with Tornado version 6.0.1
  * Set websocket.terminal to None when the child exits
* Tue Feb 13 2018 toddrme2178@gmail.com
- Disable tests until random testing race condition fixed
  * see: https://github.com/jupyter/terminado/issues/21
* Tue Nov 28 2017 arun@gmx.de
- update to version 0.8.1:
  * no changelog available
* Mon Nov 27 2017 arun@gmx.de
- update to version 0.8:
  * Add support for Windows on Python 3: #44
* Sun Nov 19 2017 arun@gmx.de
- update to version 0.7:
  * :meth:`terminado.TermSocket.open` now calls the "open()" method on
    the parent class using "super()". This allows a mixin class; for
    instance, to periodically send ping messages to keep a connection
    open.
  * When a websocket client disconnects from a terminal managed by
    :class:`~.UniqueTermManager`, the "SIGHUP" signal is sent to the
    process group, not just the main process.
  * Fixed :meth:`terminado.NamedTermManager.kill` to use the signal
    number passed to it.
  * Switched to Flit packaging.
  * README and requirements for demos.
* Mon Apr 24 2017 toddrme2178@gmail.com
- Fix URL.
- Implement single-spec version.
* Sat Apr  8 2017 toddrme2178@gmail.com
- Update to 0.6
  (no upstream changelog)
* Fri Aug 14 2015 toddrme2178@gmail.com
- Initial version
